==> haskell-test-framework-smallcheck-0.2-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-ChWTt3y8uW91umDBNF9ezl
key: test-framework-smallcheck-0.2-ChWTt3y8uW91umDBNF9ezl
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: c90407b11f1595aba10af1eb39506c96
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-ChWTt3y8uW91umDBNF9ezl
depends:
    base-4.11.1.0 smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
    test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=aec4190e63046da29e6cea1cb38a365c
             test-framework-0.8.2.0-Goo1lQ5v8lSKQXzKjc8cO4=64a691e8d693925c03bbca87367ae847
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-smallcheck-0.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-smallcheck
version: 0.2
id: test-framework-smallcheck-0.2-KYYAZBzEIYl9T6qs3za6V6
key: test-framework-smallcheck-0.2-KYYAZBzEIYl9T6qs3za6V6
license: BSD-3-Clause
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/smallcheck
synopsis: Support for SmallCheck tests in test-framework
description:
    Support for SmallCheck tests in test-framework
category: Testing
abi: d1319d949b73b112b9c386d84abb2ac3
exposed: True
exposed-modules:
    Test.Framework.Providers.SmallCheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/test-framework-smallcheck-0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/test-framework-smallcheck-0.2
hs-libraries: HStest-framework-smallcheck-0.2-KYYAZBzEIYl9T6qs3za6V6
depends:
    base-4.12.0.0 smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
    test-framework-0.8.2.0-9xKSmZ6qZ74nvowfP3MHj transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
